@@ -1,8 +1,5 @@
 # Amino acid sequence properties
 
-#' @include Alakazam.R
-NULL
-
 #### Chemical property functions ####
 
 #' Calculates the average bulkiness of amino acid sequences
@@ -25,7 +22,7 @@ NULL
 #'            in proteins by statistical methods. J Theor Biol 21, 170-201 (1968).
 #' }
 #' @seealso 
-#' For additional size related indices see \code{\link[seqinr]{aaindex}}.
+#' For additional size related indices see \link[seqinr]{aaindex}.
 #'
 #' @examples
 #' # Default bulkiness scale
@@ -113,7 +110,7 @@ polar <- function(seq, polarity=NULL) {
 
 #' Calculates the hydrophobicity of amino acid sequences
 #'
-#' \code{gravy} calculates the Grand Average of Hydrophobicity (GRAVY) index 
+#' \code{gravy} calculates the Grand Average of Hydrophobicity (gravy) index 
 #' of amino acid sequences using the method of Kyte & Doolittle. Non-informative
 #' positions are excluded, where non-informative is defined as any character in 
 #' \code{c("X", "-", ".", "*")}.
@@ -124,7 +121,7 @@ polar <- function(seq, polarity=NULL) {
 #'                       character codes. If \code{NULL}, then the Kyte & Doolittle
 #'                       scale is used.
 #' 
-#' @return   A vector of GRAVY scores for the sequence(s).
+#' @return   A vector of gravy scores for the sequence(s).
 #' 
 #' @references
 #' \enumerate{
@@ -159,7 +156,7 @@ gravy <- function(seq, hydropathy=NULL) {
     seq <- gsub("[X\\.\\*-]", "", as.character(seq))
     # Create character vector from string
     aa <- strsplit(seq, "")
-    # Calculate GRAVY
+    # Calculate gravy
     aa_gravy <- sapply(aa, function(x) sum(hydropathy[x]) / length(x))
     
     return(aa_gravy)
@@ -239,20 +236,20 @@ aliphatic <- function(seq, normalize=TRUE) {
 #' 
 #' @examples 
 #' seq <- c("CARDRSTPWRRGIASTTVRTSW", "XXTQMYVRT") 
-#' # Normalized charge
-#' charge(seq)
 #' # Unnormalized charge
-#' charge(seq, normalize=FALSE)
+#' charge(seq)
+#' # Normalized charge
+#' charge(seq, normalize=TRUE)
 #' 
 #' # Use the Murray et al, 2006 scores from the seqinr package
 #' library(seqinr)
 #' data(pK)
 #' x <- setNames(pK[["Murray"]], rownames(pK))
 #' # Calculate charge
-#' charge(seq, pK=x, normalize=FALSE)
+#' charge(seq, pK=x)
 #'
 #' @export
-charge <- function(seq, pH=7.4, pK=NULL, normalize=TRUE) {
+charge <- function(seq, pH=7.4, pK=NULL, normalize=FALSE) {
     
     # Get charge data
     if(is.null(pK)) {
@@ -288,8 +285,8 @@ charge <- function(seq, pH=7.4, pK=NULL, normalize=TRUE) {
 #' @return   A logical vector with \code{TRUE} for each valid amino acid sequences 
 #'           and \code{FALSE} for each invalid sequence.
 #' @seealso 
-#' See \code{\link{ABBREV_AA}} for the set of non-ambiguous amino acid characters.
-#' See \code{\link{IUPAC_AA}} for the full set of ambiguous amino acid characters.
+#' See \link{ABBREV_AA} for the set of non-ambiguous amino acid characters.
+#' See \link{IUPAC_AA} for the full set of ambiguous amino acid characters.
 #' 
 #' @examples 
 #' seq <- c("CARDRSTPWRRGIASTTVRTSW", "XXTQMYVR--XX", "CARJ", "10") 
@@ -356,11 +353,11 @@ countOccurrences <- function(x, pattern) {
 #'          "TGTCAGCAATATTATATTGCTCCCTTCACTTTC",
 #'          "TGTCAAAAGTATAACAGTGCCCCCTGGACGTTC")
 #' patterns <- c("A", "V", "[LI]")
-#' names(patterns) <- c("ARG", "VAL", "ISO_LEU")
-#' countPatterns(seq, patterns, nt=TRUE, trim=TRUE, label="CDR3")
+#' names(patterns) <- c("arg", "val", "iso_leu")
+#' countPatterns(seq, patterns, nt=TRUE, trim=TRUE, label="cdr3")
 #'             
 #' @export
-countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="REGION") {
+countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="region") {
     # Translate sequences if nucleotide
     region_aa <- if (nt) { translateDNA(seq, trim=trim) } else { seq }
     
@@ -408,17 +405,17 @@ countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="REGION") {
 #' 
 #' @return  A modified \code{data} data.frame with the following columns:
 #'          \itemize{
-#'            \item  \code{*_AA_LENGTH}:     number of amino acids.
-#'            \item  \code{*_AA_GRAVY}:      grand average of hydrophobicity (GRAVY) index.
-#'            \item  \code{*_AA_BULK}:       average bulkiness of amino acids.
-#'            \item  \code{*_AA_ALIPHATIC}:  aliphatic index.
-#'            \item  \code{*_AA_POLARITY}:   average polarity of amino acids.
-#'            \item  \code{*_AA_CHARGE}:     normalized net charge.
-#'            \item  \code{*_AA_BASIC}:      fraction of informative positions that are 
+#'            \item  \code{*_aa_length}:     number of amino acids.
+#'            \item  \code{*_aa_gravy}:      grand average of hydrophobicity (gravy) index.
+#'            \item  \code{*_aa_bulk}:       average bulkiness of amino acids.
+#'            \item  \code{*_aa_aliphatic}:  aliphatic index.
+#'            \item  \code{*_aa_polarity}:   average polarity of amino acids.
+#'            \item  \code{*_aa_charge}:     net charge.
+#'            \item  \code{*_aa_basic}:      fraction of informative positions that are 
 #'                                           Arg, His or Lys.
-#'            \item  \code{*_AA_ACIDIC}:     fraction of informative positions that are 
+#'            \item  \code{*_aa_acidic}:     fraction of informative positions that are 
 #'                                           Asp or Glu.
-#'            \item  \code{*_AA_AROMATIC}:   fraction of informative positions that are 
+#'            \item  \code{*_aa_aromatic}:   fraction of informative positions that are 
 #'                                           His, Phe, Trp or Tyr.
 #'            
 #'          }
@@ -430,7 +427,7 @@ countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="REGION") {
 #' For all properties except for length, non-informative positions are excluded, 
 #' where non-informative is defined as any character in \code{c("X", "-", ".", "*")}.
 #' 
-#' The scores for GRAVY, bulkiness and polarity are calculated as simple averages of the 
+#' The scores for gravy, bulkiness and polarity are calculated as simple averages of the 
 #' scores for each informative positions. The basic, acid and aromatic indices are 
 #' calculated as the fraction of informative positions falling into the given category.
 #' 
@@ -475,18 +472,16 @@ countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="REGION") {
 #' that calculate the included properties individually.
 #' 
 #' @examples
-#' # Load example data
-#' file <- system.file("extdata", "ExampleDb.gz", package="alakazam")
-#' df <- readChangeoDb(file)
-#' df <- df[c(1,10,100), c("SEQUENCE_ID", "JUNCTION")]
+#' # Subset example data
+#' db <- ExampleDb[c(1,10,100), c("sequence_id", "junction")]
 #' 
 #' # Calculate default amino acid properties from amino acid sequences
 #' # Use a custom output column prefix
-#' df$JUNCTION_TRANS <- translateDNA(df$JUNCTION)
-#' aminoAcidProperties(df, seq="JUNCTION_TRANS", label="JUNCTION")
+#' db$junction_aa <- translateDNA(db$junction)
+#' aminoAcidProperties(db, seq="junction_aa", label="junction")
 #
 #' # Calculate default amino acid properties from DNA sequences
-#' aminoAcidProperties(df, seq="JUNCTION", nt=TRUE)
+#' aminoAcidProperties(db, seq="junction", nt=TRUE)
 #' 
 #' # Use the Grantham, 1974 side chain volume scores from the seqinr package
 #' # Set pH=7.0 for the charge calculation
@@ -498,28 +493,28 @@ countPatterns <- function(seq, patterns, nt=FALSE, trim=FALSE, label="REGION") {
 #' # Rename the score vector to use single-letter codes
 #' names(x) <- translateStrings(names(x), ABBREV_AA)
 #' # Calculate properties
-#' aminoAcidProperties(df, property=c("bulk", "charge"), seq="JUNCTION", nt=TRUE, 
-#'                     trim=TRUE, label="CDR3", bulkiness=x, pH=7.0)
+#' aminoAcidProperties(db, property=c("bulk", "charge"), seq="junction", nt=TRUE, 
+#'                     trim=TRUE, label="cdr3", bulkiness=x, pH=7.0)
 #'
 #' @export
 aminoAcidProperties <- function(data, property=c("length", "gravy", "bulk",
                                                  "aliphatic","polarity","charge",
                                                  "basic","acidic", "aromatic"),
-                                seq="JUNCTION", nt=FALSE, trim=FALSE, label=NULL, ...) {
+                                seq="junction", nt=FALSE, trim=FALSE, label=NULL, ...) {
     # Check arguments
     property <- match.arg(property, several.ok=TRUE)
     
     # Define the data.frame that will be returned with amino acid properties
     prop_colnames <- list(
-        "length"    = "AA_LENGTH",
-        "gravy"     = "AA_GRAVY",
-        "bulk"      = "AA_BULK",
-        "aliphatic" = "AA_ALIPHATIC",
-        "polarity"  = "AA_POLARITY",
-        "charge"    = "AA_CHARGE",
-        "basic"     = "AA_BASIC",
-        "acidic"    = "AA_ACIDIC",
-        "aromatic"  = "AA_AROMATIC"
+        "length"    = "aa_length",
+        "gravy"     = "aa_gravy",
+        "bulk"      = "aa_bulk",
+        "aliphatic" = "aa_aliphatic",
+        "polarity"  = "aa_polarity",
+        "charge"    = "aa_charge",
+        "basic"     = "aa_basic",
+        "acidic"    = "aa_acidic",
+        "aromatic"  = "aa_aromatic"
     )
     # If no label, use sequence column name
     if (is.null(label)) { label <- seq }
